Device class

Constructors

Device()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

aspectRatio double
getter/setter pair
blockHorizontal double
getter/setter pair
blockVertical double
getter/setter pair
boxConstraints BoxConstraints
getter/setter pair
deviceType FLDeviceType
getter/setter pair
height double
getter/setter pair
orientation Orientation
getter/setter pair
pixelRatio double
getter/setter pair
screenType FLScreenType
getter/setter pair
width double
getter/setter pair

Static Methods

isLandscape(BuildContext context) → dynamic
setScreenSize(BuildContext context, BoxConstraints constraints, Orientation currentOrientation) → void